@@ -40,7 +40,7 @@
 #include <machine/ieee.h>
 #endif
 
-#if OS(QNX) && defined(_CPPLIB_VER)
+#if (OS(QNX) && defined(_CPPLIB_VER)) || COMPILER(INTEL)
 // FIXME: Look into a way to have cmath import its functions into both the standard and global
 // namespace. For now, we include math.h since the QNX cmath header only imports its functions
 // into the standard namespace.
